@@ -1,4 +1,4 @@
-/* $Id: reqs.c,v 1.105.2.2 2004/08/06 16:56:55 rjkaes Exp $
+/* $Id: reqs.c,v 1.105.2.2 2004-08-06 16:56:55 rjkaes Exp $
  *
  * This is where all the work in tinyproxy is actually done. Incoming
  * connections have a new child created for them. The child then
@@ -117,7 +117,7 @@ add_connect_port_allowed(int port)
 static int
 check_allowed_connect_ports(int port)
 {
-	ssize_t i;
+	size_t i;
 	int *data;
 
 	/*
